@@ -737,9 +737,7 @@ if __name__ == "__main__":
             )
 
         if clean:
-            # logging.warning("skipping clean because its commented")
-            pass
-            # os.remove(server_filepath)
+            os.remove(server_filepath)
 
         return str(img_id)
 
